==> opensearch-dashboards-2.4.1-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/vis_type_timeline/server/series_functions/legend.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _i18n = require("@osd/i18n");

var _alter = _interopRequireDefault(require("../lib/alter.js"));

var _chainable = _interopRequireDefault(require("../lib/classes/chainable"));

var _lib = require("../../common/lib");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var _default = new _chainable.default('legend', {
  args: [{
    name: 'inputSeries',
    types: ['seriesList']
  }, {
    name: 'position',
    types: ['string', 'boolean', 'null'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.positionHelpText', {
      defaultMessage: 'Corner to place the legend in: nw, ne, se, or sw. You can also pass false to disable the legend',
      description: '"nw", "ne", "se", "sw" and "false" are keywords and must not be translated.'
    }),
    suggestions: [{
      name: 'false',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.falseHelpText', {
        defaultMessage: 'disable legend'
      })
    }, {
      name: 'nw',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.nwHelpText', {
        defaultMessage: 'place legend in north west corner'
      })
    }, {
      name: 'ne',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.neHelpText', {
        defaultMessage: 'place legend in north east corner'
      })
    }, {
      name: 'se',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.seHelpText', {
        defaultMessage: 'place legend in south east corner'
      })
    }, {
      name: 'sw',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.swHelpText', {
        defaultMessage: 'place legend in south west corner'
      })
    }]
  }, {
    name: 'columns',
    types: ['number', 'null'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.columnsHelpText', {
      defaultMessage: 'Number of columns to divide the legend into'
    })
  }, {
    name: 'showTime',
    types: ['boolean'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.showTimeHelpText', {
      defaultMessage: 'Show time value in legend when hovering over graph. Default: true'
    })
  }, {
    name: 'timeFormat',
    types: ['string'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.timeFormatHelpText', {
      defaultMessage: 'moment.js format pattern. Default: {defaultTimeFormat}',
      values: {
        defaultTimeFormat: _lib.DEFAULT_TIME_FORMAT
      }
    })
  }],
  help: _i18n.i18n.translate('timeline.help.functions.legendHelpText', {
    defaultMessage: 'Set the position and style of the legend on the plot'
  }),
  fn: function legendFn(args) {
    return (0, _alter.default)(args, function (eachSeries, position, columns, showTime = true, timeFormat = _lib.DEFAULT_TIME_FORMAT) {
      eachSeries._global = eachSeries._global || {};
      eachSeries._global.legend = eachSeries._global.legend || {};
      eachSeries._global.legend.noColumns = columns;
      eachSeries._global.legend.showTime = showTime;
      eachSeries._global.legend.timeFormat = timeFormat;

      if (position === false) {
        eachSeries._global.legend.show = false;
        eachSeries._global.legend.showTime = false;
      } else {
        eachSeries._global.legend.position = position;
      }

      return eachSeries;
    });
  }
});

exports.default = _default;
module.exports = exports.default;

==> opensearch-dashboards-3.1.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/vis_type_timeline/server/series_functions/legend.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _i18n = require("@osd/i18n");
var _alter = _interopRequireDefault(require("../lib/alter.js"));
var _chainable = _interopRequireDefault(require("../lib/classes/chainable"));
var _lib = require("../../common/lib");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var _default = exports.default = new _chainable.default('legend', {
  args: [{
    name: 'inputSeries',
    types: ['seriesList']
  }, {
    name: 'position',
    types: ['string', 'boolean', 'null'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.positionHelpText', {
      defaultMessage: 'Corner to place the legend in: nw, ne, se, or sw. You can also pass false to disable the legend',
      description: '"nw", "ne", "se", "sw" and "false" are keywords and must not be translated.'
    }),
    suggestions: [{
      name: 'false',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.falseHelpText', {
        defaultMessage: 'disable legend'
      })
    }, {
      name: 'nw',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.nwHelpText', {
        defaultMessage: 'place legend in north west corner'
      })
    }, {
      name: 'ne',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.neHelpText', {
        defaultMessage: 'place legend in north east corner'
      })
    }, {
      name: 'se',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.seHelpText', {
        defaultMessage: 'place legend in south east corner'
      })
    }, {
      name: 'sw',
      help: _i18n.i18n.translate('timeline.help.functions.legend.args.position.suggestions.swHelpText', {
        defaultMessage: 'place legend in south west corner'
      })
    }]
  }, {
    name: 'columns',
    types: ['number', 'null'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.columnsHelpText', {
      defaultMessage: 'Number of columns to divide the legend into'
    })
  }, {
    name: 'showTime',
    types: ['boolean'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.showTimeHelpText', {
      defaultMessage: 'Show time value in legend when hovering over graph. Default: true'
    })
  }, {
    name: 'timeFormat',
    types: ['string'],
    help: _i18n.i18n.translate('timeline.help.functions.legend.args.timeFormatHelpText', {
      defaultMessage: 'moment.js format pattern. Default: {defaultTimeFormat}',
      values: {
        defaultTimeFormat: _lib.DEFAULT_TIME_FORMAT
      }
    })
  }],
  help: _i18n.i18n.translate('timeline.help.functions.legendHelpText', {
    defaultMessage: 'Set the position and style of the legend on the plot'
  }),
  fn: function legendFn(args) {
    return (0, _alter.default)(args, function (eachSeries, position, columns, showTime = true, timeFormat = _lib.DEFAULT_TIME_FORMAT) {
      eachSeries._global = eachSeries._global || {};
      eachSeries._global.legend = eachSeries._global.legend || {};
      eachSeries._global.legend.noColumns = columns;
      eachSeries._global.legend.showTime = showTime;
      eachSeries._global.legend.timeFormat = timeFormat;
      if (position === false) {
        eachSeries._global.legend.show = false;
        eachSeries._global.legend.showTime = false;
      } else {
        eachSeries._global.legend.position = position;
      }
      return eachSeries;
    });
  }
});
module.exports = exports.default;
